package com.mkaz;

/**
 * @(#) htmllib.java  0.74  2000-01-04 
 *
 * @author Marcus Kazmierczak, marcus@mkaz.com
 * @version 0.74
 *
 *  ====================================================================
 *  Copyright (c) 1998-2000 Marcus Kazmierczak, marcus@mkaz.com
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 *  3. All advertising materials mentioning features or use of this software
 *     must display the following acknowledgement:
 *          "This product includes software developed by mkaz.com"
 *
 *  4. The name of the author may not be used to endorse or promote products
 *     derived from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 *  IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 *  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 *  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 *  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 *  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  ====================================================================
 *
 */

import java.util.*;

	/**
	  * com.mkaz.htmllib is a java library which provides shortcut methods 
	  * to ease the development of html documents (code). This can be compared
	  * to CGI.pm for Perl. Many of the commands and shortcuts
	  * available in CGI.pm are (or will be) available here.
	  * <BLOCKQUOTE>
	  * <P><B>Example Usage:</B><BR>
	  * <PRE>
	  *
	  *      htmllib html = new htmllib();	
	  * 
	  *      // create a link
 	  *      out.println(html.link("web blazonry","http://blazonry.com/"));
	  * </PRE>
	  * </BLOCKQUOTE>
      */

	 public class htmllib {


		/**
		  * Main Constructor. You need to create an htmllib object to
		  * use the rest of the functions. <BR>
		  * <P>Example: <CODE> htmllib html = new htmllib(); </CODE>
		  *
		  */	  
		  public htmllib() {
				
		  }

       /**
         * Creates a complete HTML header with DOCTYPE 4.0T, HTML, HEAD, TITLE and BODY tags.
		 * Default background color is white.
		 *
		 * @param title  title of the HTML page (string)
		 * @return  HTML header as a string
		 */
		  public String header(String title) {
				String retval;

				retval  = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\" ";
				retval += "\"http://www.w3.org/TR/REC-html40/loose.dtd\">\n";
				retval += "<HTML>\n";
				retval += "<HEAD>\n";
				retval += "<TITLE>"+title+"</TITLE>\n";
				retval += "</HEAD>\n";
				retval += "<BODY BGCOLOR=\"#FFFFFF\">";

				return retval;
		  }


       /**
         * Creates a complete HTML header with DOCTYPE 4.0T, HTML, HEAD, TITLE and BODY tags.
			*
			* @param title  title of the HTML page (string)
			* @param bgcolor  HTML color hex (with #), or color name for background
			* @return  HTML header as a string
			*/
		  public String header(String title, String bgcolor) {
				String retval;

				retval  = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\" ";
				retval += "\"http://www.w3.org/TR/REC-html40/loose.dtd\">\n";
				retval += "<HTML>\n";
				retval += "<HEAD>\n";
				retval += "<TITLE>"+title+"</TITLE>\n";
				retval += "</HEAD>\n";
				retval += "<BODY BGCOLOR=\""+bgcolor+"\">";

				return retval;
		  }


//------------------------------------------------------------------------------------------------
//------- ***  TEXT ELEMENTS  ***  ---------------------------------------------------------------
//------------------------------------------------------------------------------------------------

		  /**
			* Creates an HTML H1 
			*
			* @param string text to be H1
			* @return string with H1 tags added
			*/		  
		  public String h1(String str) { return "<H1>"+str+"</H1>"; }

		  /**
			* Creates an HTML H2
			*
			* @param string text to be H2
			* @return string with H2 tags added
			*/		  
		  public String h2(String str) { return "<H2>"+str+"</H2>"; }

		  /**
			* Creates an HTML H3
			*
			* @param string text to be H3
			* @return string with H3 tags added
			*/		  
		  public String h3(String str) { return "<H3>"+str+"</H3>"; }


		  /**
			* Creates an HTML H4
			*
			* @param string text to be H4
			* @return string with H4 tags added
			*/		  
		  public String h4(String str) { return "<H4>"+str+"</H4>"; }		  

		  /**
			* Creates an HTML H5
			*
			* @param string text to be H5
			* @return string with H5 tags added
			*/		  
		  public String h5(String str) { return "<H5>"+str+"</H5>"; }

		  /**
			* Creates an HTML H6
			*
			* @param string text to be H6
			* @return string with H6 tags added
			*/		  
		  public String h6(String str) { return "<H6>"+str+"</H6>"; }


		  /**
			* Creates a bold piece of text
			*
			* @param string text to be bolded
			* @return string with bold tags added
			*/
		  public String b(String str) { return "<B>"+str+"</B>"; }

		  /**
			* Creates an italic piece of text
			*
			* @param string text to be italic
			* @return string with italic tags added
			*/
		  public String i(String str) { return "<B>"+str+"</B>"; }

		  
		  /** 
			* Creates an HTML A HREF link.
			*
			* @param desc  the description of the link, ie. the (blue) part that shows up
			* on screen.
			* @param url   the URL to set the link to
			* @return  string &lt;A HREF="url"&gt;desc&lt;/A&gt; 
			*/
		  public String link(String desc, String url) 
		  { 
				return "<A HREF=\""+url+"\">"+desc+"</A>"; 
		  }
		  
//------------------------------------------------------------------------------------------------
//------- ***  TABLE ELEMENTS  ***  ---------------------------------------------------------------
//------------------------------------------------------------------------------------------------

		  /**
			* Create a "blank" table tag.
			* 
			* @return string "blank" starting table tag
			*/
		  public String table() { return "<TABLE>"; }


		  /**
			* Creates an end table tag.
			* 
			* @return string ending table tag
			*/
		  public String endtable() { return "</TABLE>"; }


		  /**
			* Creates a table tag with padding, spacing and border
			*
			* @param padding  int CELLPADDING for table
			* @param spacing  int CELLSPACING for table
			* @param border  int BORDER width for table
			*
			* @return  string table with padding, spacing and border
			*/
		  public String table(int padding, int spacing, int border) {
				return "<TABLE CELLPADDING=\""+padding+"\" CELLSPACING=\""+spacing+"\" BORDER=\""+border+"\">\n";
		  }


		  /**
			* Creates a table tag with padding, spacing, border and width
			*
			* @param padding  int CELLPADDING for table
			* @param spacing  int CELLSPACING for table
			* @param border  int BORDER width for table
			* @param width  string width of table (% or px)
			*
			* @return  string table with padding, spacing, border and width
			*/
		  public String table(int padding, int spacing, int border, String width) {
				return "<TABLE CELLPADDING=\""+padding+"\" CELLSPACING=\""+spacing+"\" BORDER=\""+border+"\" WIDTH=\""+width+"\">\n";
		  }

	
		  /**
			* Creates a two col table header row
			* 
			* @param col1  string contents for col1
			* @param col2  string contents for col2
			*
			* @return html table header row with two cols as a string
			*/
		  public String hrow(String col1, String col2) {
				return "<TR><TH VALIGN=\"TOP\">"+col1+"</TH><TH VALIGN=\"TOP\">"+col2+"</TH></TR>\n";
		  }


		  /**
			* Creates a three col table header row.
			* 
			* @param col1  string contents for col1
			* @param col2  string contents for col2
			* @param col3  string contents for col3
			*
			* @return html table header row with three cols as a string
			*/
		  public String hrow(String col1, String col2, String col3) {
				return "<TR><TH VALIGN=\"TOP\">"+col1+"</TH><TH VALIGN=\"TOP\">"+col2+"</TH><TH VALIGN=\"TOP\">"+col3+"</TH></TR>\n";
		  }
		  
		  /**
			* Creates a four col table header row
			* 
			* @param col1  string contents for col1
			* @param col2  string contents for col2
			* @param col3  string contents for col3
			* @param col4  string contents for col4
			*
			* @return html table header row with four cols as a string
			*/
		  public String hrow(String col1, String col2, String col3, String col4) {
				return "<TR><TH VALIGN=\"TOP\">"+col1+"</TH><TH VALIGN=\"TOP\">"+col2+"</TH><TH VALIGN=\"TOP\">"+col3+"</TH><TH VALIGN=\"TOP\">"+col4+"</TH></TR>\n";
		  }


		  /**
			* Creates a table header row from an array
			* 
			* @param col  string array of columns
			*
			* @return html table header row with array length columns
			*/
		  public String hrow(String[] col) {
				String retstr="";
				int i;
				retstr = "<TR>";
				for (i=0; i<col.length; i++) {
					 retstr += "<TH VALIGN=\"TOP\">"+col[i]+"</TH>";
				}
				retstr += "</TR>";

				return retstr;
		  }


		  /**
			* Creates a two col table row
			* 
			* @param col1  string contents for col1
			* @param col2  string contents for col2
			*
			* @return html table row with two cols as a string
			*/
		  public String row(String col1, String col2) {
				return "<TR><TD VALIGN=\"TOP\">"+col1+"</TD><TD VALIGN=\"TOP\">"+col2+"</TD></TR>\n";
		  }

		  /**
			* Creates a three col table row.
			* 
			* @param col1  string contents for col1
			* @param col2  string contents for col2
			* @param col3  string contents for col3
			*
			* @return html table row with three cols as a string
			*/
		  public String row(String col1, String col2, String col3) {
				return "<TR><TD VALIGN=\"TOP\">"+col1+"</TD><TD VALIGN=\"TOP\">"+col2+"</TD><TD VALIGN=\"TOP\">"+col3+"</TD></TR>\n";
		  }
		  
		  /**
			* Creates a four col table row
			* 
			* @param col1  string contents for col1
			* @param col2  string contents for col2
			* @param col3  string contents for col3
			* @param col4  string contents for col4
			*
			* @return html table row with four cols as a string
			*/
		  public String row(String col1, String col2, String col3, String col4) {
				return "<TR><TD VALIGN=\"TOP\">"+col1+"</TD><TD VALIGN=\"TOP\">"+col2+"</TD><TD VALIGN=\"TOP\">"+col3+"</TD><TD VALIGN=\"TOP\">"+col4+"</TD></TR>\n";
		  }

		  /**
			* Creates a table row from an array
			* 
			* @param col  string array of columns
			*
			* @return html table  row with array length columns
			*/
		  public String row(String[] col) {
				String retstr="";
				int i;
				retstr = "<TR>";
				for (i=0; i<col.length; i++) {
					 retstr += "<TD VALIGN=\"TOP\">"+col[i]+"</TD>";
				}
				retstr += "</TR>";

				return retstr;
		  }
//------------------------------------------------------------------------------------------------
//------- ***  FANCY TABLE ELEMENTS  ***  ---------------------------------------------------------------
//------------------------------------------------------------------------------------------------


		  /**
			* Creates an end table tag for fancy table
			* 
			* @return string ending table tag
			*/
		  public String endftable() { return "</TABLE></TD></TR></TABLE>"; }


		  /**
			* Creates a fancy table tag with color1 border and color2 background (padding=4 spacing=0)
			*
			* @param color1  String BORDER color for fancy table
			* @param color2  String BACKGROUND for fancy table
			* @param width	 String WIDTH of the fancy table
			*
			* @return  string fancy table start tags
			*/
		  public String ftable(String color1, String color2, String width) {
				String retval;

				retval  = "<TABLE CELLPADDING=1 CELLSPACING=0 BORDER=0 BGCOLOR=\""+color1+"\" WIDTH=\""+width+"\"><TR><TD>\n";
				retval += "<TABLE CELLPADDING=4 CELLSPACING=1 BORDER=0 BGCOLOR=\""+color2+"\" WIDTH=\"100%\">\n";

				return retval;
		  }
	
		  /**
			* Creates a two col table header row
			* 
			* @param col1  string contents for col1
			* @param col2  string contents for col2
			* @param bgcolor string background color
			*
			* @return html table header row with two cols as a string and background color
			*/
		  public String hfrow(String col1, String col2, String bgcolor) {
				return "<TR BGCOLOR=\""+bgcolor+"\"><TD VALIGN=\"TOP\"><B>"+col1+"</B></TD><TD VALIGN=\"TOP\"><B>"+col2+"</B></TD></TR>\n";
		  }


		  /**
			* Creates a three col table header row.
			* 
			* @param col1  string contents for col1
			* @param col2  string contents for col2
			* @param col3  string contents for col3
			* @param bgcolor string background color
			*
			* @return html table header row with three cols as a string and background color
			*/
		  public String hfrow(String col1, String col2, String col3, String bgcolor) {
				return "<TR BGCOLOR=\""+bgcolor+"\"><TD VALIGN=\"TOP\"><B>"+col1+"</B></TD><TD VALIGN=\"TOP\"><B>"+col2+"</B></TD><TD VALIGN=\"TOP\"><B>"+col3+"</B></TD></TR>\n";
		  }
		  
		  /**
			* Creates a four col table header row
			* 
			* @param col1  string contents for col1
			* @param col2  string contents for col2
			* @param col3  string contents for col3
			* @param col4  string contents for col4
			* @param bgcolor string background color
			*	
			* @return html table header row with four cols as a string and background color
			*/
		  public String hfrow(String col1, String col2, String col3, String col4, String bgcolor) {
				return "<TR BGCOLOR=\""+bgcolor+"\"><TD VALIGN=\"TOP\"><B>"+col1+"</B></TD><TD VALIGN=\"TOP\"><B>"+col2+"</B></TD><TD VALIGN=\"TOP\"><B>"+col3+"</B></TD><TD VALIGN=\"TOP\"><B>"+col4+"</B></TD></TR>\n";
		  }


		  /**
			* Creates a table header row from an array
			* 
			* @param col  string array of columns
			* @param bgcolor string background color
		 	* 
			* @return html table header row with array length columns
			*/
		  public String hfrow(String[] col, String bgcolor) {
				String retstr="";
				int i;
				retstr = "<TR BGCOLOR=\""+bgcolor+"\">";
				for (i=0; i<col.length; i++) {
					 retstr += "<TD VALIGN=\"TOP\"><B>"+col[i]+"</B></TD>";
				}
				retstr += "</TR>";

				return retstr;
		  }



//------------------------------------------------------------------------------------------------
//------- ***  IMAGE ELEMENTS  ***  ---------------------------------------------------------------
//------------------------------------------------------------------------------------------------


		  /**
			* Creates an image tag
			* 
			* @param image  string link to image
			* @param alt  string alternate text
			*
			* @return html image tag
			*/
		  public String img(String image, String alt) {
				return "<IMG SRC=\""+image+"\" ALT=\""+alt+"\" BORDER=0>";
		  }


		  /**
			* Creates an image tag with width, height, and alternate text
			* 
			* @param image  string link to image
			* @param width  int width of image
			* @param height int height of image
			* @param alt    string alternate text
			*
			* @return html image tag
			*/
		  public String img(String image, int width, int height, String alt) {
				return "<IMG SRC=\""+image+"\" WIDTH=\""+width+"\" HEIGHT=\""+height+"\" ALT=\""+alt+"\" BORDER=0>";
		  }

//------------------------------------------------------------------------------------------------
//------- ***  FORM ELEMENTS  ***  ---------------------------------------------------------------
//------------------------------------------------------------------------------------------------



		  /**
			* Creates a form tag with action url and method
			* 
			* @param action  url to submit the form to, action field in form
			* @param method  GET or POST
			*
			* @return String html start form tag
			*/
		  public String form(String action, String method) {
				return "<FORM ACTION=\""+action+"\" METHOD=\""+method+"\">";
		  }

		  /**
			* Creates a hidden form element with name, value
			* 
			* @param name String hidden field name
			* @param value String hidden field value
			*
			* @return String html hidden form element
			*/
		  public String hidden(String name, String value) {
				return "<INPUT TYPE=hidden NAME=\""+name+"\" VALUE=\""+value+"\">";
		  }		 


		  /**
			* Creates a submit button form element with value
			* 
			* @param value string text displayed on the button
			*
			* @return String html form submit button
			*/
		  public String submit(String value) {
				return "<INPUT TYPE=submit VALUE=\""+value+"\">";
		  }		 


		  /**
			* Creates a text form element with name, value, size, maxlength
			* 
			* @param name string text field name
			* @param value string text field default value
			* @param size int text field width
			* @param maxlength int text field maximum length
			*
			* @return String html text form element
			*/
		  public String text(String name, String value, int size, int maxlength) {
				return "<INPUT TYPE=text NAME=\""+name+"\" VALUE=\""+value+"\" SIZE=\""+size+"\" MAXLENGTH=\""+maxlength+"\">";
		  }		 

		  /**
			* Creates a password form element with name, size, maxlength
			* 
			* @param name string text field name
			* @param size int text field width
			* @param maxlength int text field maximum length
			*
			* @return String html password form element
			*/
		  public String password(String name, int size, int maxlength) {
				return "<INPUT TYPE=password NAME=\""+name+"\" SIZE=\""+size+"\" MAXLENGTH=\""+maxlength+"\">";
		  }		 


		  /**
			* Creates a textarea form element with name, value, rows, cols (wrap on)
			* 
			* @param name String textarea field name
			* @param value String textarea field default value
			* @param rows int number of rows in textarea
			* @param cols int number of columns in textarea
			*
			* @return String html textarea form element
			*/
		  public String textarea(String name, String value, int rows, int cols) {
				return "<TEXTAREA NAME=\""+name+"\" ROWS=\""+rows+"\" COLS=\""+cols+"\" WRAP>"+value+"</TEXTAREA>";
		  }		  


		  /**
			* Creates a select field with options
			* 
			* @param fieldname name of the select field
			* @param options Hashtable of options with the option value set to the hashkey, and the display value set to the hashvalue
			*
			* @return String html select field and option tags form elements
			*/
		  public String selectfield(String fieldname, Hashtable options) {
				String retval="";
				String thiskey = "";
				
				retval = "<SELECT NAME=\""+fieldname+"\"";
				
				Enumeration e = options.keys();
				while (e.hasMoreElements()) {
					thiskey = (String)e.nextElement();

					retval += "<OPTION VALUE=\""+thiskey+"\">"+options.get(thiskey)+"\n";

				}
				retval += "</SELECT>";

				return retval;
		  }


	 }

